@@ -1,6 +1,7 @@
 # 市场
-MARKET_SZ = 0  # 深圳
-MARKET_SH = 1  # 上海
+MARKET_SZ = 0  # 深市
+MARKET_SH = 1  # 沪市
+MARKET_BJ = 2  # 北交
 
 # K线种类
 # 0 -   5 分钟K 线
@@ -75,3 +76,8 @@ CONFIG = {
     'BESTIP': {'HQ': '', 'EX': '', 'GP': ''},
     'TDXDIR': 'C:/new_tdx',
 }
+
+
+def return_last_value(retry_state):
+    """return the result of the last call attempt"""
+    return retry_state.outcome.result()
