@@ -8,7 +8,7 @@ from pytdx.errors import TdxConnectionError
 from pytdx.heartbeat import HqHeartBeatThread
 from pytdx.reader import TdxDailyBarReader
 
-from mootdx.logger import log
+from mootdx.logger import logger
 
 
 class MooTdxDailyBarReader(TdxDailyBarReader):
@@ -80,7 +80,7 @@ class MooTdxDailyBarReader(TdxDailyBarReader):
             if code_head in ['01', '10', '11', '12', '13', '14']:
                 return 'SH_BOND'
         else:
-            log.error('Unknown security exchange !\n')
+            logger.error('Unknown security exchange !\n')
             raise NotImplementedError
 
 
@@ -103,7 +103,7 @@ class MooBaseSocketClient(BaseSocketClient):
         self.client = TrafficStatSocket(socket.AF_INET, socket.SOCK_STREAM)
         self.client.settimeout(time_out)
 
-        log.debug('connecting to server : %s on port :%d' % (ip, port))
+        logger.debug('connecting to server : %s on port :%d' % (ip, port))
 
         try:
             self.ip = ip
@@ -114,21 +114,21 @@ class MooBaseSocketClient(BaseSocketClient):
 
             self.client.connect((ip, port))
         except socket.timeout as e:
-            log.debug(e)
-            log.debug('connection expired')
+            logger.debug(e)
+            logger.debug('connection expired')
 
             if self.raise_exception:
                 raise TdxConnectionError('connection timeout error')
 
             return False
         except Exception as e:
-            log.debug(e)
+            logger.debug(e)
             if self.raise_exception:
                 raise TdxConnectionError('other errors')
 
             return False
 
-        log.debug('connected!')
+        logger.debug('connected!')
 
         if self.need_setup:
             self.setup()
@@ -146,19 +146,19 @@ class MooBaseSocketClient(BaseSocketClient):
             self.stop_event.set()
 
         if self.client:
-            log.debug('disconnecting')
+            logger.debug('disconnecting')
 
             try:
                 self.client.shutdown(socket.SHUT_RDWR)
                 self.client.close()
                 self.client = None
             except Exception as e:
-                log.debug(str(e))
+                logger.debug(str(e))
 
                 if self.raise_exception:
                     raise TdxConnectionError('disconnect err')
 
-            log.debug('disconnected')
+            logger.debug('disconnected')
 
     def setup(self):
         pass
