@@ -8,8 +8,10 @@ import httpx
 import pandas as pd
 from tenacity import stop_after_attempt, wait_fixed, retry
 
+from mootdx.consts import return_last_value
 
-@retry(wait=wait_fixed(2), stop=stop_after_attempt(5))
+
+@retry(wait=wait_fixed(2), retry_error_callback=return_last_value, stop=stop_after_attempt(5))
 def fq_factor(method: str, symbol: str) -> pd.DataFrame:
     zh_sina_a_stock_hfq_url = "https://finance.sina.com.cn/realstock/company/{}/hfq.js"
     zh_sina_a_stock_qfq_url = "https://finance.sina.com.cn/realstock/company/{}/qfq.js"
